pub struct PfsImage<'a> {
pub data: &'a [u8],
pub ekpfs: &'a [u8],
}Expand description
The embedded PFS image and its encryption key, returned by Pkg::get_pfs_image().
Fields
data: &'a [u8]The raw PFS image bytes.
ekpfs: &'a [u8]The EKPFS key needed to decrypt and open the PFS.